@@ -5,6 +5,7 @@ from typing import Any, Dict, Optional, cast
 import click
 import yaml
 
+from ..airbyte_utils import AirbyteFactory
 from ..bi_utils import BiAction, bi
 from ..cli_configs import find_datahub_config_file
 from ..cli_constants import BUILD_DIR
@@ -37,6 +38,8 @@ class DeployCommand:
     e.g. path to a token, username, password, etc."""
     env: str
     bi_git_key_path: str
+    auth_token: Optional[str]
+    """Authorization OIDC ID token for a service account to communication with Airbyte instance"""
 
     def __init__(
         self,
@@ -46,12 +49,14 @@ class DeployCommand:
         provider_kwargs_dict: Optional[Dict[str, Any]],
         datahub_ingest: bool,
         bi_git_key_path: str,
+        auth_token: Optional[str],
     ) -> None:
         self.docker_args = DockerArgs(env, None, {}) if docker_push else None
         self.datahub_ingest = datahub_ingest
         self.provider_kwargs_dict = provider_kwargs_dict or {}
         self.env = env
         self.bi_git_key_path = bi_git_key_path
+        self.auth_token = auth_token
 
         try:
             self.blob_address_path = (
@@ -65,6 +70,10 @@ class DeployCommand:
         except KeyError as key_error:
             raise AirflowDagsPathKeyError from key_error
 
+        self.enable_ingest = read_dictionary_from_config_directory(
+            BUILD_DIR.joinpath("dag"), env, "ingestion.yml"
+        ).get("enable", False)
+
     def deploy(self) -> None:
         """Push and deploy the project to the remote machine.
 
@@ -77,6 +86,9 @@ class DeployCommand:
         if self.datahub_ingest:
             self._datahub_ingest()
 
+        if self.enable_ingest:
+            self._enable_ingest()
+
         self._bi_push()
 
         self._sync_bucket()
@@ -132,6 +144,13 @@ class DeployCommand:
             ]
         )
 
+    def _enable_ingest(self) -> None:
+        echo_info("Ingesting airbyte config")
+        airbyte_config_path = AirbyteFactory.find_config_file(self.env, "airbyte")
+        AirbyteFactory(
+            airbyte_config_path=airbyte_config_path, auth_token=self.auth_token
+        ).create_update_connections()
+
     def _sync_bucket(self) -> None:
         echo_info("Syncing Bucket")
         LocalRemoteSync(
@@ -171,6 +190,12 @@ class DeployCommand:
     required=False,
     help="Path to the key with write access to repo",
 )
+@click.option(
+    "--auth-token",
+    type=str,
+    required=False,
+    help="Authorization OIDC ID token for a service account to communication with cloud services",
+)
 def deploy_command(
     env: str,
     dags_path: Optional[str],
@@ -178,6 +203,7 @@ def deploy_command(
     docker_push: bool,
     datahub_ingest: bool,
     bi_git_key_path: str,
+    auth_token: Optional[str],
 ) -> None:
     if blob_args:
         try:
@@ -189,5 +215,11 @@ def deploy_command(
         provider_kwargs_dict = None
 
     DeployCommand(
-        env, docker_push, dags_path, provider_kwargs_dict, datahub_ingest, bi_git_key_path
+        env,
+        docker_push,
+        dags_path,
+        provider_kwargs_dict,
+        datahub_ingest,
+        bi_git_key_path,
+        auth_token,
     ).deploy()
